fwd package
===========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   fwd.tests

Submodules
----------

fwd.fwd module
--------------

.. automodule:: fwd.fwd
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: fwd
   :members:
   :undoc-members:
   :show-inheritance:
